@@ -10,6 +10,10 @@ int appClose=0;
 float average_speed=0;
 float seconds=0;
 //LocationThread l;
+int d_speed=0;
+float d_trip=0;
+float d_total=0;
+float d_average=0;
 
 
 Speedo::Speedo(QWidget *parent) :
@@ -98,14 +102,8 @@ void Speedo::updateLocation()
     else
         average_speed=0;
     average_speed*=3.6f; // km / h
-    int d_speed;
-    float d_trip;
-    float d_total;
-    float d_average;
-    QString sUnit;
     if(unit==0)
     {
-        sUnit="km";
         //ui->label->setText("km/h");
         //ui->label_2->setText("km (trip)");
         //ui->label_3->setText("km");
@@ -118,7 +116,6 @@ void Speedo::updateLocation()
     }
     else
     {
-        sUnit="mi";
         d_speed =(int)(speed/1.609);
         d_trip = trip/1.609;
         d_total=total/1.609;
@@ -130,9 +127,19 @@ void Speedo::updateLocation()
 
     }
 
+
+}
+
+void Speedo::updateTime()
+{
+
+    QString sUnit;
+    if(unit==0)sUnit="km";else sUnit="mi";
+
     char buf[20];
     if(display==0)
     {
+        ui->lcdNumber->setDigitCount(3);
         ui->lcdNumber->display(d_speed);
         QString text;
         text=sUnit+"/h";
@@ -140,8 +147,9 @@ void Speedo::updateLocation()
     }
     else if(display==1)
     {
+        ui->lcdNumber->setDigitCount(7);
         sprintf(buf,"%.2f",d_trip);
-    // replace , with . for QLcdNumber
+        // replace , with . for QLcdNumber
     for(unsigned int i=0;i<strlen(buf);i++){
         if(buf[i]==',')buf[i]='.';}
     QString text=sUnit+" (trip)";
@@ -150,6 +158,7 @@ void Speedo::updateLocation()
     }
     else if(display==2)
     {
+        ui->lcdNumber->setDigitCount(7);
     sprintf(buf,"%.2f",d_total);
     // replace , with . for QLcdNumber
     for(unsigned int i=0;i<strlen(buf);i++){
@@ -159,6 +168,7 @@ void Speedo::updateLocation()
     }
     else if(display==3)
     {
+        ui->lcdNumber->setDigitCount(7);
     sprintf(buf,"%.2f",d_average);
     // replace , with . for QLcdNumber
     for(unsigned int i=0;i<strlen(buf);i++){
@@ -167,14 +177,9 @@ void Speedo::updateLocation()
     QString text=sUnit+"/h (avg.speed)";
     ui->label->setText(text);
     }
-
-}
-
-void Speedo::updateTime()
-{
-
-    if(display==4)
+    else if(display==4)
     {
+        ui->lcdNumber->setDigitCount(10);
         char buf[80];char h[3],m[3],s[3];
         if(hour<10)sprintf(h,"0%d",hour);else sprintf(h,"%d",hour);
         if(min<10)sprintf(m,"0%d",min);else sprintf(m,"%d",min);
